---
layout: "vault"
page_title: "Vault: vault_aws_secret_backend resource"
sidebar_current: "docs-vault-resource-aws-secret-backend"
description: |-
  Creates an AWS secret backend for Vault.
---

# vault\_aws\_secret\_backend

Creates an AWS Secret Backend for Vault. AWS secret backends can then issue AWS
access keys and secret keys, once a role has been added to the backend.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_aws_secret_backend" "aws" {
  access_key = "AKIA....."
  secret_key = "AWS secret key"
}
```

## Argument Reference

The following arguments are supported:

* `access_key` - (Optional) The AWS Access Key ID this backend should use to
issue new credentials. Vault uses the official AWS SDK to authenticate, and thus can also use standard AWS environment credentials, shared file credentials or IAM role/ECS task credentials.

* `secret_key` - (Optional) The AWS Secret Key this backend should use to
issue new credentials. Vault uses the official AWS SDK to authenticate, and thus can also use standard AWS environment credentials, shared file credentials or IAM role/ECS task credentials.

~> **Important** Vault version 1.2.3 and older does not support reading the configured
credentials back from the API, With these older versions, Terraform cannot detect and correct drift
on `access_key` or `secret_key`. Changing the values, however, _will_
overwrite the previously stored values. With versions of Vault newer than
1.2.3, reading the `access_key` only is supported, and so drifts of the
`access_key` will be detected and corrected, but drifts on the `secret_key`
will not.

* `region` - (Optional) The AWS region for API calls. Defaults to `us-east-1`.

~> **Important** The same limitation noted above for the `access_key` parameter
also applies to the `region` parameter. Vault versions 1.2.3 and older will not
allow Terraform to detect (and thus correct) drift in the `region` parameter,
while newer versions of Vault will.

* `path` - (Optional) The unique path this backend should be mounted at. Must
not begin or end with a `/`. Defaults to `aws`.

* `description` - (Optional) A human-friendly description for this backend.

* `default_lease_ttl_seconds` - (Optional) The default TTL for credentials
issued by this backend.

* `max_lease_ttl_seconds` - (Optional) The maximum TTL that can be requested
for credentials issued by this backend.

## Attributes Reference

No additional attributes are exported by this resource.

## Import

AWS secret backends can be imported using the `path`, e.g.

```
$ terraform import vault_aws_secret_backend.aws aws
```
