---
layout: "vault"
page_title: "Vault: vault_consul_secret_backend resource"
sidebar_current: "docs-vault-resource-consul-secret-backend"
description: |-
  Creates a Consul secret backend for Vault.
---

# vault\_consul\_secret\_backend

Creates a Consul Secret Backend for Vault. Consul secret backends can then issue Consul tokens, once a role has been added to the backend.

~> **Important** All data provided in the resource configuration will be
written in cleartext to state and plan files generated by Terraform, and
will appear in the console output when Terraform runs. Protect these
artifacts accordingly. See
[the main provider documentation](../index.html)
for more details.

## Example Usage

```hcl
resource "vault_consul_secret_backend" "test" {
  path        = "consul"
  description = "Manages the Consul backend"

  address = "127.0.0.1:8500"
  token   = "4240861b-ce3d-8530-115a-521ff070dd29"
}
```

## Argument Reference

The following arguments are supported:

* `token` - (Required) The Consul management token this backend should use to issue new tokens.

~> **Important** Because Vault does not support reading the configured
token back from the API, Terraform cannot detect and correct drift
on `token`. Changing the value, however, _will_ overwrite the previously stored values.

* `path` - (Optional) The unique location this backend should be mounted at. Must not begin or end with a `/`. Defaults to `consul`.

* `description` - (Optional) A human-friendly description for this backend.

* `address` - (Required) Specifies the address of the Consul instance, provided as "host:port" like "127.0.0.1:8500".

* `scheme` - (Optional) Specifies the URL scheme to use. Defaults to `http`.

* `default_lease_ttl_seconds` - (Optional) The default TTL for credentials issued by this backend.

* `max_lease_ttl_seconds` - (Optional) The maximum TTL that can be requested
for credentials issued by this backend.

## Attributes Reference

No additional attributes are exported by this resource.

## Import

Consul secret backends can be imported using the `path`, e.g.

```
$ terraform import vault_consul_secret_backend.example consul
```
